/// An enumeration that represents all possible static assets folder where assets included into the `DocC`catalog and code generated by the `DocC` building process. will be stored.
enum AssetPrefix: String, CaseIterable {
    /// A folder that contains all CSS code generated by the `DocC` building process.
    case css
    /// A folder that contains all documentation data extracted from the source code by the `DocC` building process.
    case data
    /// A folder that contains all other resources included into the `DocC` documentation catalog.
    case downloads
    /// A folder that contains all image resources included into the `DocC` documentation catalog.
    case images
    /// A folder that contains all image resources included into the `DocC` documentation catalog.
    case img
    /// A folder that contains all `HTML` code generated by the `DocC` building process.
    case index
    /// A folder that contains all `Javascript` code generated by the `DocC` building process.
    case js
    /// A folder that contains all video resources included into the `DocC` documentation catalog.
    case videos
}

// MARK: - Pathable

extension AssetPrefix: Pathable {
    
    // MARK: Computed
    
    var path: String {
        .init(format: .Format.Path.folder, rawValue)
    }
    
}
